pitchtools.chromatic_pitch_names_string_to_named_chromatic_pitch_list
=====================================================================

.. autofunction:: abjad.tools.pitchtools.chromatic_pitch_names_string_to_named_chromatic_pitch_list.chromatic_pitch_names_string_to_named_chromatic_pitch_list
